@@ -1,15 +1,19 @@
 import json
+import logging
 import platform
 import sys
 import time
 import uuid
 from base64 import standard_b64encode as b64
-from typing import Any, Dict, List, Optional
+from typing import Any, Dict, List, Optional, cast
 
 import requests
 
-from dagster import Failure, Field, IntSource, RetryRequested, StringSource, check, resource
-from dagster.core.utils import coerce_valid_log_level
+from dagster import Failure, Field, IntSource, RetryRequested, StringSource
+from dagster import _check as check
+from dagster import resource
+from dagster._core.definitions.resource_definition import ResourceDefinition
+from dagster._core.utils import coerce_valid_log_level
 
 from ..dbt_resource import DbtResource
 from .types import DbtRpcOutput
@@ -76,7 +80,7 @@ class DbtRpcResource(DbtResource):
         headers["User-Agent"] = self._construct_user_agent()
         headers["Content-Type"] = "application/json"
         headers["Accept"] = "application/json"
-        return headers
+        return cast(Dict[str, str], headers)
 
     def _post(self, data: Optional[str] = None) -> DbtRpcOutput:
         """Constructs and sends a POST request to the dbt RPC server.
@@ -138,8 +142,8 @@ class DbtRpcResource(DbtResource):
         return self._jsonrpc_version
 
     @property
-    def logger(self) -> Optional[Any]:
-        """Optional[Any]: A property for injecting a logger dependency."""
+    def logger(self) -> logging.Logger:
+        """logging.Logger: A property for injecting a logger dependency."""
         return self._logger
 
     @property
@@ -455,6 +459,41 @@ class DbtRpcResource(DbtResource):
 
         return self._get_result(data=json.dumps(data))
 
+    def build(self, select: Optional[List[str]] = None, **kwargs) -> DbtRpcOutput:
+        """
+        Run the ``build`` command on a dbt project. kwargs are passed in as additional parameters.
+
+        Args:
+            select (List[str], optional): the models/resources to include in the run.
+
+        Returns:
+            DbtOutput: object containing parsed output from dbt
+        """
+        ...  # pylint: disable=unnecessary-ellipsis
+        raise NotImplementedError()
+
+    def get_run_results_json(self, **kwargs) -> Optional[Dict[str, Any]]:
+        """
+        Get a parsed version of the run_results.json file for the relevant dbt project.
+
+        Returns:
+            Dict[str, Any]: dictionary containing the parsed contents of the run_results json file
+                for this dbt project.
+        """
+        ...  # pylint: disable=unnecessary-ellipsis
+        raise NotImplementedError()
+
+    def get_manifest_json(self, **kwargs) -> Optional[Dict[str, Any]]:
+        """
+        Get a parsed version of the manifest.json file for the relevant dbt project.
+
+        Returns:
+            Dict[str, Any]: dictionary containing the parsed contents of the manifest json file
+                for this dbt project.
+        """
+        ...  # pylint: disable=unnecessary-ellipsis
+        raise NotImplementedError()
+
 
 class DbtRpcSyncResource(DbtRpcResource):
     def __init__(
@@ -481,10 +520,11 @@ class DbtRpcSyncResource(DbtRpcResource):
         self.poll_interval = poll_interval
 
     def _get_result(self, data: Optional[str] = None) -> DbtRpcOutput:
-        """Sends a request to the dbt RPC server and continuously polls for the status of a request until the state is ``success``."""
+        """Sends a request to the dbt RPC server and continuously polls for the status of a request
+        until the state is ``success``."""
 
         out = super()._get_result(data)
-        request_token = out.result.get("request_token")
+        request_token: str = check.not_none(out.result.get("request_token"))
 
         logs_start = 0
 
@@ -537,7 +577,7 @@ def dbt_rpc_resource(context) -> DbtRpcResource:
     """This resource defines a dbt RPC client.
 
     To configure this resource, we recommend using the `configured
-    <https://docs.dagster.io/overview/configuration#configured>`_ method.
+    <https://docs.dagster.io/concepts/configuration/configured>`_ method.
 
     Examples:
 
@@ -574,7 +614,7 @@ def dbt_rpc_sync_resource(
     and waits for the request to complete before returning.
 
     To configure this resource, we recommend using the `configured
-    <https://docs.dagster.io/overview/configuration#configured>`_ method.
+    <https://docs.dagster.io/concepts/configuration/configured>`_ method.
 
     Examples:
 
@@ -596,6 +636,8 @@ def dbt_rpc_sync_resource(
     )
 
 
-local_dbt_rpc_resource = dbt_rpc_resource.configured({"host": "0.0.0.0", "port": 8580})
+local_dbt_rpc_resource = cast(
+    ResourceDefinition, dbt_rpc_resource.configured({"host": "0.0.0.0", "port": 8580})
+)
 local_dbt_rpc_resource.__doc__ = """This resource defines a dbt RPC client for an RPC server running
 on 0.0.0.0:8580."""
